@@ -73,10 +73,7 @@ LearnerClassifLogReg = R6Class("LearnerClassifLogReg",
   private = list(
     .train = function(task) {
       pv = self$param_set$get_values(tags = "train")
-
-      if ("weights" %in% task$properties) {
-        pv = insert_named(pv, list(weights = task$weights$weight))
-      }
+      pv$weights = get_weights(task, private)
 
       form = task$formula()
       data = task$data()
