@@ -106,7 +106,7 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
         disable_default_eval_metric = p_lgl(default = FALSE, tags = "train"),
         early_stopping_rounds       = p_int(1L, default = NULL, special_vals = list(NULL), tags = "train"),
         eta                         = p_dbl(0, 1, default = 0.3, tags = c("train", "control")),
-        eval_metric                 = p_uty(tags = "train", custom_check = crate({function(x) check_true(any(is.character(x), is.function(x), inherits(x, "Measure")))})),
+        eval_metric                 = p_uty(tags = "train", custom_check = crate({function(x) check_true(any(is.character(x), is.function(x), test_multi_class(x, c("MeasureClassifSimple", "MeasureBinarySimple"))))})),
         feature_selector            = p_fct(c("cyclic", "shuffle", "random", "greedy", "thrifty"), default = "cyclic", tags = "train", depends = quote(booster == "gblinear")),
         gamma                       = p_dbl(0, default = 0, tags = c("train", "control")),
         grow_policy                 = p_fct(c("depthwise", "lossguide"), default = "depthwise", tags = "train", depends = quote(tree_method == "hist")),
@@ -129,10 +129,6 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
         num_parallel_tree           = p_int(1L, default = 1L, tags = c("train", "control")),
         objective                   = p_uty(default = "binary:logistic", tags = c("train", "predict", "control")),
         one_drop                    = p_lgl(default = FALSE, tags = "train", depends = quote(booster == "dart")),
-        outputmargin                = p_lgl(default = FALSE, tags = "predict"),
-        predcontrib                 = p_lgl(default = FALSE, tags = "predict"),
-        predinteraction             = p_lgl(default = FALSE, tags = "predict"),
-        predleaf                    = p_lgl(default = FALSE, tags = "predict"),
         print_every_n               = p_int(1L, default = 1L, tags = "train", depends = quote(verbose == 1L)),
         process_type                = p_fct(c("default", "update"), default = "default", tags = "train"),
         rate_drop                   = p_dbl(0, 1, default = 0, tags = "train", depends = quote(booster == "dart")),
@@ -222,6 +218,10 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
       lvls = task$class_names
       nlvls = length(lvls)
 
+      if (isTRUE(pv$predcontrib) || isTRUE(pv$predinteraction) || isTRUE(pv$predleaf)) {
+        warningf("Predicting contributions, interactions, or leaf values with $predict() is not supported. ")
+      }
+
       if (is.null(pv$objective)) {
         pv$objective = if (nlvls == 2L) "binary:logistic" else "multi:softprob"
       }
@@ -425,7 +425,7 @@ LearnerClassifXgboost = R6Class("LearnerClassifXgboost",
 #' @export
 default_values.LearnerClassifXgboost = function(x, search_space, task, ...) { # nolint
   special_defaults = list(
-    nrounds = 1L
+    nrounds = 1000L
   )
   defaults = insert_named(default_values(x$param_set), special_defaults)
   defaults[search_space$ids()]
