@@ -86,7 +86,7 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
         disable_default_eval_metric = p_lgl(default = FALSE, tags = "train"),
         early_stopping_rounds       = p_int(1L, default = NULL, special_vals = list(NULL), tags = "train"),
         eta                         = p_dbl(0, 1, default = 0.3, tags = "train"),
-        eval_metric                 = p_uty(default = "rmse", tags = "train", custom_check = crate({function(x) check_true(any(is.character(x), is.function(x), inherits(x, "Measure")))})),
+        eval_metric                 = p_uty(default = "rmse", tags = "train", custom_check = crate({function(x) check_true(any(is.character(x), is.function(x), inherits(x, "MeasureRegrSimple")))})),
         feature_selector            = p_fct(c("cyclic", "shuffle", "random", "greedy", "thrifty"), default = "cyclic", tags = "train", depends = quote(booster == "gblinear")),
         gamma                       = p_dbl(0, default = 0, tags = "train"),
         grow_policy                 = p_fct(c("depthwise", "lossguide"), default = "depthwise", tags = "train", depends = quote(tree_method == "hist")),
@@ -109,10 +109,6 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
         num_parallel_tree           = p_int(1L, default = 1L, tags = "train"),
         objective                   = p_uty(default = "reg:squarederror", tags = c("train", "predict")),
         one_drop                    = p_lgl(default = FALSE, tags = "train", depends = quote(booster == "dart")),
-        outputmargin                = p_lgl(default = FALSE, tags = "predict"),
-        predcontrib                 = p_lgl(default = FALSE, tags = "predict"),
-        predinteraction             = p_lgl(default = FALSE, tags = "predict"),
-        predleaf                    = p_lgl(default = FALSE, tags = "predict"),
         print_every_n               = p_int(1L, default = 1L, tags = "train", depends = quote(verbose == 1L)),
         process_type                = p_fct(c("default", "update"), default = "default", tags = "train"),
         rate_drop                   = p_dbl(0, 1, default = 0, tags = "train", depends = quote(booster == "dart")),
@@ -314,7 +310,7 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
 #' @export
 default_values.LearnerRegrXgboost = function(x, search_space, task, ...) { # nolint
   special_defaults = list(
-    nrounds = 1L
+    nrounds = 1000L
   )
   defaults = insert_named(default_values(x$param_set), special_defaults)
   defaults[search_space$ids()]
