@@ -1,5 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(mlr3learners)
+  library("testthat")
+  library("mlr3learners")
   test_check("mlr3learners")
 }
