@@ -97,3 +97,12 @@ test_that("selected_features", {
   learner$train(task)
   expect_set_equal(learner$selected_features(), c("Sepal.Length", "Sepal.Width", "Petal.Length", "Petal.Width"))
 })
+
+test_that("oob_error available without stored model", {
+  task = tsk("pima")
+  learner = lrn("classif.ranger")
+
+  rr = resample(task, learner, rsmp("holdout"), store_models = FALSE)
+
+  expect_number(rr$aggregate(msr("oob_error")))
+})
